@@ -1,5 +1,5 @@
 package Yahoo::Marketing::APT::AdGroupNonGuaranteedSettings;
-# Copyright (c) 2008 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -15,7 +15,6 @@ Yahoo::Marketing::APT::AdGroupNonGuaranteedSettings - a data object to represent
 sub _user_setable_attributes {
     return ( qw/ 
                  ROITarget
-                 adOptimization
                  bidDescriptor
             /  );
 }
@@ -33,7 +32,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://help.yahoo.com/l/us/yahoo/amp/webservices/reference/data/> for documentation of the various data objects.
+See L<http://help.yahoo.com/l/us/yahoo/apt/webservices/reference/data/> for documentation of the various data objects.
 
 
 =cut
@@ -49,7 +48,6 @@ Creates a new instance
 =over 8
 
     ROITarget
-    adOptimization
     bidDescriptor
 
 =back
