@@ -9,13 +9,14 @@ use Test::More;
 
 use Yahoo::Marketing::APT::ReportRequest;
 
-sub test_can_create_report_request_and_set_all_fields : Test(7) {
+sub test_can_create_report_request_and_set_all_fields : Test(8) {
 
     my $report_request = Yahoo::Marketing::APT::ReportRequest->new
                                                         ->contextID( 'context id' )
                                                         ->dataGrouping( 'data grouping' )
                                                         ->dateRange( 'date range' )
                                                         ->endDate( '2009-01-06T17:51:55' )
+							->reportCurrency( 'report currency' )
                                                         ->reportName( 'report name' )
                                                         ->startDate( '2009-01-07T17:51:55' )
                    ;
@@ -26,6 +27,7 @@ sub test_can_create_report_request_and_set_all_fields : Test(7) {
     is( $report_request->dataGrouping, 'data grouping', 'can get data grouping' );
     is( $report_request->dateRange, 'date range', 'can get date range' );
     is( $report_request->endDate, '2009-01-06T17:51:55', 'can get 2009-01-06T17:51:55' );
+    is( $report_request->reportCurrency, 'report currency' );
     is( $report_request->reportName, 'report name', 'can get report name' );
     is( $report_request->startDate, '2009-01-07T17:51:55', 'can get 2009-01-07T17:51:55' );
 
